#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# If you update this list, please also update
# doc/source/features.rst.
SUPPORTED_API_EXTENSIONS = [
    'agent',
    'quotas',
    'extra_dhcp_opt',
    'binding',
    'dhcp_agent_scheduler',
    'security-group',
    'external-net',
    'router',
    'l3_agent_scheduler',
    'subnet_allocation',
    'port-security',
    'allowed-address-pairs',
    'net-mtu',
    'default-subnetpools',
    'extraroute',
]
